%
% This file implements the method described in:
%
% "Robust Region Detection via Consensus Segmentation of Deformable Shapes"
% E. Rodola, S. Rota Bulo, and D. Cremers
% Computer Graphics Forum, 33(5), 2014
%
% If you use this code, please cite the paper above.
% 
% Emanuele Rodola (c) 2014
%
function keys = create_ensemble(descr, weights, params)

% Segment the given shape many times with k-means

n_runs = params.consensus_n_segmentations;
clusters_per_run = params.kmeans_k;

m = size(descr,1);

keys = zeros(m,n_runs);

fprintf('Constructing ensemble... ');

parfor i=1:n_runs
    keys(:,i) = fkmeans(descr, clusters_per_run, struct('weight', weights));
end

fprintf('done.\n');

end
